Welcome to Normalization’s documentation! — Normalization 0 documentation

# Welcome to Normalization’s documentation!

Contents

- Installation
- Loading
  - Loading via folders
  - Loading via individual file name
  - Loading via list file names
  - Loading via arrays
  - Loading with Auto Gamma Filtering
  - Loading with Manual Gamma Filtering
- Dark Field Correction
- Normalization
  - Normalization using ROI (optional)
  - Normalization without ROI
  - Forcing normalization by mean OB
- Cropping Data
- Retrieve Normalized Data
- Export Data

# Indices and tables

- Index
- Module Index
- Search Page